#####################################################################################################################
#WHO Bibliometric Analysis
#coding by Sophie Huddart
#sophie.huddart@mail.mcgill.ca

#June 6th, 2017 - 
#####################################################################################################################

########### Setting up this file ############
setwd("~/Dropbox/2017/WHO Bibliometric Analysis/Complete Search Analysis")

require(bibliometrix)
require(plyr)
require(stringr)
require(xtable)

#############################################

######### Notes ######################
#Web of science search run June 8th:
#TITLE: (tuberculosis) AND YEAR PUBLISHED: (2006-2016) 
#36,540 hits


#Version 1 - Preliminary exploration of bibliometrix capabilities
#Version 2
  ## Dropped 2006 to get 10 years
#Version 3 
  ## Added high-middle/low income country collaboration
#Version 4
  ##Avg % year on year increase
  ## Top 5 countries over time
  ## BRICS vs non-BRICS over time
#Version 5
  ##Added IF to top journals (in LaTeX)
#Version 6
  ##Created SVG versions of the graphics
#Version 7
  ##SA using fractional paper attribution to country
######################################

########## Data read-in ###############
#bibfiles_2006 <- readFiles("Data/websci_2006_1.bib", "Data/websci_2006_501.bib", 'Data/websci_2006_1001.bib',
#                          "Data/websci_2006_1501.bib", "Data/websci_2006_2001.bib")
#y2006<- convert2df(bibfiles_2006, dbsource = "isi", format = "bibtex")
#2,055 verified

bibfiles_2007 <- readFiles("Data/websci_2007_1.bib", "Data/websci_2007_501.bib", 'Data/websci_2007_1001.bib',
                           "Data/websci_2007_1501.bib", "Data/websci_2007_2001.bib")
y2007<- convert2df(bibfiles_2007, dbsource = "isi", format = "bibtex")
#2,434 verified

bibfiles_2008 <- readFiles("Data/websci_2008_1.bib", "Data/websci_2008_501.bib", 'Data/websci_2008_1001.bib',
                           "Data/websci_2008_1501.bib", "Data/websci_2008_2001.bib","Data/websci_2008_2501.bib")
y2008<- convert2df(bibfiles_2008, dbsource = "isi", format = "bibtex")
#2,512 verified

bibfiles_2009 <- readFiles("Data/websci_2009_1.bib", "Data/websci_2009_501.bib", 'Data/websci_2009_1001.bib',
                           "Data/websci_2009_1501.bib", "Data/websci_2009_2001.bib","Data/websci_2009_2501.bib")
y2009<- convert2df(bibfiles_2009, dbsource = "isi", format = "bibtex")
#2,766 verified

bibfiles_2010 <- readFiles("Data/websci_2010_1.bib", "Data/websci_2010_501.bib", 'Data/websci_2010_1001.bib',
                           "Data/websci_2010_1501.bib", "Data/websci_2010_2001.bib","Data/websci_2010_2501.bib",
                           "Data/websci_2010_3001.bib")
y2010<- convert2df(bibfiles_2010, dbsource = "isi", format = "bibtex")
#3,001 verified

bibfiles_2011 <- readFiles("Data/websci_2011_1.bib", "Data/websci_2011_501.bib", 'Data/websci_2011_1001.bib',
                           "Data/websci_2011_1501.bib", "Data/websci_2011_2001.bib","Data/websci_2011_2501.bib",
                           "Data/websci_2011_3001.bib")
y2011<- convert2df(bibfiles_2011, dbsource = "isi", format = "bibtex")
#3,423 verified

bibfiles_2012 <- readFiles("Data/websci_2012_1.bib", "Data/websci_2012_501.bib", 'Data/websci_2012_1001.bib',
                           "Data/websci_2012_1501.bib", "Data/websci_2012_2001.bib","Data/websci_2012_2501.bib",
                           "Data/websci_2012_3001.bib", "Data/websci_2012_3501.bib")
y2012<- convert2df(bibfiles_2012, dbsource = "isi", format = "bibtex")
#3,584 verified

bibfiles_2013 <- readFiles("Data/websci_2013_1.bib", "Data/websci_2013_501.bib", 'Data/websci_2013_1001.bib',
                           "Data/websci_2013_1501.bib", "Data/websci_2013_2001.bib","Data/websci_2013_2501.bib",
                           "Data/websci_2013_3001.bib", "Data/websci_2013_3501.bib")
y2013<- convert2df(bibfiles_2013, dbsource = "isi", format = "bibtex")
#3,916 verified


bibfiles_2014 <- readFiles("Data/websci_2014_1.bib", "Data/websci_2014_501.bib", 'Data/websci_2014_1001.bib',
                           "Data/websci_2014_1501.bib", "Data/websci_2014_2001.bib","Data/websci_2014_2501.bib",
                           "Data/websci_2014_3001.bib", "Data/websci_2014_3501.bib")
y2014<- convert2df(bibfiles_2014, dbsource = "isi", format = "bibtex")
#3,946 verified

bibfiles_2015 <- readFiles("Data/websci_2015_1.bib", "Data/websci_2015_501.bib", 'Data/websci_2015_1001.bib',
                           "Data/websci_2015_1501.bib", "Data/websci_2015_2001.bib","Data/websci_2015_2501.bib",
                           "Data/websci_2015_3001.bib", "Data/websci_2015_3501.bib", "Data/websci_2015_4001.bib")
y2015<- convert2df(bibfiles_2015, dbsource = "isi", format = "bibtex")
#4,376 verified

bibfiles_2016 <- readFiles("Data/websci_2016_1.bib", "Data/websci_2016_501.bib", 'Data/websci_2016_1001.bib',
                           "Data/websci_2016_1501.bib", "Data/websci_2016_2001.bib","Data/websci_2016_2501.bib",
                           "Data/websci_2016_3001.bib", "Data/websci_2016_3501.bib", "Data/websci_2016_4001.bib",
                           "Data/websci_2016_4501.bib")
y2016<- convert2df(bibfiles_2016, dbsource = "isi", format = "bibtex")
#4,554 verified


yall<-rbind(y2007,y2008,y2009,y2010,y2011,y2012,y2013,y2014, y2015,y2016)
#######################################

#######Summary of overall #############

biball<-biblioAnalysis(yall, sep=';')

summary(biball)
plot(biball, k=10)

#######################################

####### Number of papers over time ####
art_year<-c(dim(y2007)[1],dim(y2008)[1],dim(y2009)[1],dim(y2010)[1],dim(y2011)[1],dim(y2012)[1],
            dim(y2013)[1],dim(y2014)[1],dim(y2015)[1],dim(y2016)[1])
years<-c('2007','2008','2009','2010','2011','2012','2013','2014','2015','2016')

#pdf(width=6, height=5, file="articlesbyyear.pdf")
par(mar=c(5,5,4,2)) # increase y-axis margin.
barplot(art_year, main="", names.arg=years, cex.names=1.1, ylim=c(0,5000))
#dev.off()


##Year on year increase
round(mean(diff(art_year, lag=1)/art_year[1:9])*100,2)
#average 7.29% increase year on year
#######################################

######## Top countries over time ########
bib_2007<-biblioAnalysis(y2007, sep=';')
country_2007<-count(bib_2007$CO)
country_2007<-country_2007[order(country_2007$freq, decreasing = TRUE),]

bib_2008<-biblioAnalysis(y2008, sep=';')
country_2008<-count(bib_2008$CO)
country_2008<-country_2008[order(country_2008$freq, decreasing = TRUE),]

bib_2009<-biblioAnalysis(y2009, sep=';')
country_2009<-count(bib_2009$CO)
country_2009<-country_2009[order(country_2009$freq, decreasing = TRUE),]

bib_2010<-biblioAnalysis(y2010, sep=';')
country_2010<-count(bib_2010$CO)
country_2010<-country_2010[order(country_2010$freq, decreasing = TRUE),]

bib_2011<-biblioAnalysis(y2011, sep=';')
country_2011<-count(bib_2011$CO)
country_2011<-country_2011[order(country_2011$freq, decreasing = TRUE),]

bib_2011<-biblioAnalysis(y2011, sep=';')
country_2011<-count(bib_2011$CO)
country_2011<-country_2011[order(country_2011$freq, decreasing = TRUE),]

bib_2012<-biblioAnalysis(y2012, sep=';')
country_2012<-count(bib_2012$CO)
country_2012<-country_2012[order(country_2012$freq, decreasing = TRUE),]

bib_2013<-biblioAnalysis(y2013, sep=';')
country_2013<-count(bib_2013$CO)
country_2013<-country_2013[order(country_2013$freq, decreasing = TRUE),]

bib_2014<-biblioAnalysis(y2014, sep=';')
country_2014<-count(bib_2014$CO)
country_2014<-country_2014[order(country_2014$freq, decreasing = TRUE),]

bib_2015<-biblioAnalysis(y2015, sep=';')
country_2015<-count(bib_2015$CO)
country_2015<-country_2015[order(country_2015$freq, decreasing = TRUE),]

bib_2016<-biblioAnalysis(y2016, sep=';')
country_2016<-count(bib_2016$CO)
country_2016<-country_2016[order(country_2016$freq, decreasing = TRUE),]

mat_country<-matrix(nrow=7, ncol=10)
row.names(mat_country)<-c('USA',"India","China", "England","South Africa", "Other", "Not listed")
colnames(mat_country)<-years


topcountrycount<-function(country_table, tab, i){
tab[1,i]<-country_table$freq[country_table$x=="USA"&!is.na(country_table$x)]
tab[2,i]<-country_table$freq[country_table$x=="INDIA"&!is.na(country_table$x)]
tab[3,i]<-country_table$freq[country_table$x=="CHINA"&!is.na(country_table$x)]
tab[4,i]<-country_table$freq[country_table$x=="ENGLAND"&!is.na(country_table$x)]
tab[5,i]<-country_table$freq[country_table$x=="SOUTH AFRICA"&!is.na(country_table$x)]
tab[7,i]<-country_table$freq[is.na(country_table$x)]
tab[6,i]<-sum(country_table$freq)-sum(tab[1:5,i])-tab[7,i]
return(tab)}

mat_country<-topcountrycount(country_2007,mat_country,1)
mat_country<-topcountrycount(country_2008,mat_country,2)
mat_country<-topcountrycount(country_2009,mat_country,3)
mat_country<-topcountrycount(country_2010,mat_country,4)
mat_country<-topcountrycount(country_2011,mat_country,5)
mat_country<-topcountrycount(country_2012,mat_country,6)
mat_country<-topcountrycount(country_2013,mat_country,7)
mat_country<-topcountrycount(country_2014,mat_country,8)
mat_country<-topcountrycount(country_2015,mat_country,9)
mat_country<-topcountrycount(country_2016,mat_country,10)

svg(file="year_country.svg", width=6, height=4)
par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_country, col=7:1, xlab="Year", ylab="Number of papers")
legend('topright', col=7:1, rownames(mat_country), pch=15, cex=.5, inset=c(-.2,0), pt.cex=1)
dev.off()

denom<-apply(mat_country, 2, sum)
mat_countryprop<-mat_country

for(i in 1:10){
  mat_countryprop[,i]<-mat_country[,i]/denom[i]
}

#mat_countryprop<-round(mat_countryprop,4)
par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_countryprop, col=7:1, xlab="Year", ylab="Proportion of annual papers")
legend('topright', col=7:1, rownames(mat_country), pch=15, cex=.5, horiz=FALSE, inset=c(-.2,0), pt.cex=1)
########################################

######### BRICS over time #############
mat_brics<-matrix(nrow=8, ncol=10)
row.names(mat_brics)<-c("Brazil", 'Russia','India','China','South Africa','BRICS', 'Other','Not listed')
colnames(mat_brics)<-years


bricscountrycount<-function(country_table, tab, i){
  tab[1,i]<-country_table$freq[country_table$x=="BRAZIL"&!is.na(country_table$x)]
  tab[2,i]<-country_table$freq[country_table$x=="RUSSIA"&!is.na(country_table$x)]
  tab[3,i]<-country_table$freq[country_table$x=="INDIA"&!is.na(country_table$x)]
  tab[4,i]<-country_table$freq[country_table$x=="CHINA"&!is.na(country_table$x)]
  tab[5,i]<-country_table$freq[country_table$x=="SOUTH AFRICA"&!is.na(country_table$x)]
  tab[6,i]<-sum(tab[1:5,i])
  tab[8,i]<-country_table$freq[is.na(country_table$x)]
  tab[7,i]<-sum(country_table$freq)-sum(tab[1:5,i])-tab[8,i]
  return(tab)}

mat_brics<-bricscountrycount(country_2007,mat_brics,1)
mat_brics<-bricscountrycount(country_2008,mat_brics,2)
mat_brics<-bricscountrycount(country_2009,mat_brics,3)
mat_brics<-bricscountrycount(country_2010,mat_brics,4)
mat_brics<-bricscountrycount(country_2011,mat_brics,5)
mat_brics<-bricscountrycount(country_2012,mat_brics,6)
mat_brics<-bricscountrycount(country_2013,mat_brics,7)
mat_brics<-bricscountrycount(country_2014,mat_brics,8)
mat_brics<-bricscountrycount(country_2015,mat_brics,9)
mat_brics<-bricscountrycount(country_2016,mat_brics,10)

#BRICS year graph
par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_brics[6:8,], col=3:1, xlab="Year", ylab="Number of papers")
legend('topright', col=3:1,c("BRICS", "Non-BRICS", "Not listed") , pch=15, cex=.5, inset=c(-.2,0), pt.cex=1)

svg(file="year_bricsall.svg", width=6, height=4)
par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_brics[-6,], col=7:1, xlab="Year", ylab="Number of papers")
legend('topright', col=7:1,row.names(mat_brics)[-6] , pch=15, cex=.5, inset=c(-.2,0), pt.cex=1)
dev.off()

#BRICS year prop graph
mat_bricsprop<-mat_brics
for(i in 1:10){
  mat_bricsprop[,i]<-mat_brics[,i]/denom[i]
}

par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_bricsprop[6:8,], col=3:1, xlab="Year", ylab="Proportion of annual papers")
legend('topright', col=3:1, c("BRICS", "Non-BRICS", "Not listed"), pch=15, cex=.5, horiz=FALSE, inset=c(-.2,0), pt.cex=1)

par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_bricsprop[-6,], col=7:1, xlab="Year", ylab="Proportion of annual papers")
legend('topright', col=7:1,row.names(mat_brics)[-6] , pch=15, cex=.5, inset=c(-.2,0), pt.cex=1)
#BRICS year on year % change

round(mean(diff(mat_brics[6,], lag=1)/mat_brics[6,1:9])*100,2)
#average 13.10% increase year on year


#Overall proprotion BRICS 
sum(mat_brics[6,])/dim(yall)[1]*100

#2007 proportion
sum(mat_brics[6,1])/dim(y2007)[1]*100
#2016 proportion
sum(mat_brics[6,10])/dim(y2016)[1]*100
######################################


######## Top 10 journals ##### 
#handmade tables
#######################################

######## Top 10 countries ##### 

mat_top10<-matrix(nrow=10, ncol=4)
row.names(mat_top10)<-1:10
colnames(mat_top10)<-c( "Country", "n", "%", "95% CI")

bib_all<-biblioAnalysis(yall, sep=';')
country_all<-count(bib_all$CO)
country_all<-country_all[order(country_all$freq, decreasing = TRUE),]
length(country_all$x)


CIstring<-function(prop, n){
  ptest<-prop.test(x=(prop/100)*n,n=n)
  return(paste("(", round(ptest$conf.int[1]*100,1), ", ",round(ptest$conf.int[2]*100,1), ")", sep="" ))
}

mat_top10[,1]<-as.character(country_all$x[c(1,2,3,4,6,7,8,9,10,11)])
mat_top10[,2]<-country_all$freq[c(1,2,3,4,6,7,8,9,10,11)]
mat_top10[,3]<-round((mat_top10[,2]/sum(country_all$freq))*100,1)

for (i in 1:10){
  mat_top10[i,4]<-CIstring(as.numeric(mat_top10[i,3]), sum(country_all$freq))
}

print(xtable(mat_top10, caption = "Top publishing countries from 2007 to 2016"), comment=TRUE, booktabs=TRUE)

#######################################

######## Top 5 network over time ##### 
#2007
meta_extraction_2007 <- metaTagExtraction(y2007, Field = "AU_CO", sep = ";")
#country_matrix_2007 <- cocMatrix(meta_extraction, Field = "AU_CO", sep = ";")
NetMatrix_2007 <- biblioNetwork(meta_extraction_2007, analysis = "collaboration", network = "countries", sep = ";")
# Plot the network
net=networkPlot(NetMatrix_2007, n = 5, Title = "2007", type = "circle", size=FALSE, remove.multiple=FALSE, labelsize = 1)



#2012
meta_extraction_2012 <- metaTagExtraction(y2012, Field = "AU_CO", sep = ";")
#country_matrix_2012 <- cocMatrix(meta_extraction, Field = "AU_CO", sep = ";")
NetMatrix_2012 <- biblioNetwork(meta_extraction_2012, analysis = "collaboration", network = "countries", sep = ";")
# Plot the network
net=networkPlot(NetMatrix_2012, n = 5, Title = "2012", type = "circle", size=FALSE, remove.multiple=FALSE, labelsize = 1)

#2016
meta_extraction_2016 <- metaTagExtraction(y2016, Field = "AU_CO", sep = ";")
#country_matrix_2016 <- cocMatrix(meta_extraction, Field = "AU_CO", sep = ";")
NetMatrix_2016 <- biblioNetwork(meta_extraction_2016, analysis = "collaboration", network = "countries", sep = ";")
# Plot the network
net=networkPlot(NetMatrix_2016, n = 5, Title = "2016", type = "circle", size=FALSE, remove.multiple=FALSE, labelsize = 1)

#######################################

######## Top Cited Articles ##########
cit<- citations(yall, field = "article", sep = ".  ")
cit$Cited[1:10]
######################################


#### Collaboration by country income level ####
y2007$C1[2]
income<-read.csv('income.csv', as.is = TRUE)
unique(income$Income.group)
high<-income$Economy[income$Income.group=="High income"]
middle<-income$Economy[income$Income.group=="Middle income"]
low<-income$Economy[income$Income.group=="Low income"]

find.country<-function(strings, countries){
  found<-rep(NA, length(strings))
  for(j in 1:length(strings)){
    no_punc<-gsub("[[:punct:]]", "", strings[j])
    for(i in 1:length(countries)){
      found[j]<-grepl(countries[i], no_punc, ignore.case = TRUE)
      if (found[j]==TRUE) break
      }
    }
  return(found)
}
yall_income<-yall
yall_income$high.income<-rep(NA, dim(yall_income)[1])
yall_income$middle.income<-rep(NA, dim(yall_income)[1])
yall_income$low.income<-rep(NA, dim(yall_income)[1])
yall_income$high.income<-find.country(yall$C1, high)
yall_income$middle.income<-find.country(yall$C1, middle)
yall_income$low.income<-find.country(yall$C1, low)

#Number of papers with authors from low income countries
sum(yall_income$low.income)
round(sum(yall_income$low.income)/length(yall_income$low.income)*100,1)

#Number of papers with authors from middle income countries
sum(yall_income$middle.income)
round(sum(yall_income$middle.income)/length(yall_income$middle.income)*100,1)

#Number of papers with authors from high income countries
sum(yall_income$high.income)
round(sum(yall_income$high.income)/length(yall_income$high.income)*100,1)

#Number of countries overall with high and low income collab
tab_collab<-matrix(nrow=3, ncol=11)
row.names(tab_collab)<-c('High-Low', "High-Middle", "High-Low/Middle")
colnames(tab_collab)<-c(as.character(seq(2007,2016)), "Overall")
denom_collab<-c(tapply(yall_income$PY, yall_income$PY, length), dim(yall)[1])

tab_collab[1,]<-(c(tapply(yall_income$high.income==TRUE&yall_income$low.income==TRUE, yall_income$PY, sum), 
                   sum(yall_income$high.income==TRUE&yall_income$low.income==TRUE))/
                   denom_collab)*100
tab_collab[2,]<-(c(tapply(yall_income$high.income==TRUE&yall_income$middle.income==TRUE, yall_income$PY, sum), 
                   sum(yall_income$high.income==TRUE&yall_income$middle.income==TRUE))/
                   denom_collab)*100
tab_collab[3,]<-(c(tapply(yall_income$high.income==TRUE&(yall_income$low.income==TRUE|yall_income$middle.income==TRUE), yall_income$PY, sum), 
                   sum(yall_income$high.income==TRUE&(yall_income$low.income==TRUE|yall_income$middle.income==TRUE)))/
                   denom_collab)*100
tab_collab<-round(tab_collab,1)

svg(file="highLMICcollab.svg", height = 4.5, width = 6 )
{plot(0:9,tab_collab[3,1:10], type='l', ylim=c(10,30), col=2, ylab='Proportion, %', xaxt='n', xlab='')
  axis(1, at=0:9, labels=colnames(tab_collab)[1:10])}
dev.off()

print(xtable(tab_collab, caption = "Proportion of papers with authors from high and low or middle income countries"), comment=TRUE, booktabs=TRUE)
###############################################

#### Fractional author attributions ####
library(stringr)
country_all<-metaTagExtraction(yall, Field = "AU_CO", sep = ";")

####BRICS over time with fractional authorship####
country_all$tot<-rep(NA, dim(country_all)[1])
country_all$Brazil<-rep(NA, dim(country_all)[1])
country_all$Russia<-rep(NA, dim(country_all)[1])
country_all$India<-rep(NA, dim(country_all)[1])
country_all$China<-rep(NA, dim(country_all)[1])
country_all$SAfrica<-rep(NA, dim(country_all)[1])
country_all$not_listed<-rep(NA, dim(country_all)[1])
country_all$other<-rep(NA, dim(country_all)[1])
country_all$BRICS<-rep(NA, dim(country_all)[1])

country_all$tot<-str_count(country_all$AU_CO, pattern=";")+1
country_all$Brazil<-str_count(country_all$AU_CO, pattern="BRAZIL")/country_all$tot
country_all$Russia<-str_count(country_all$AU_CO, pattern="RUSSIA")/country_all$tot
country_all$India<-str_count(country_all$AU_CO, pattern="INDIA")/country_all$tot
country_all$China<-str_count(country_all$AU_CO, pattern="CHINA")/country_all$tot
country_all$SAfrica<-str_count(country_all$AU_CO, pattern="SOUTH AFRICA")/country_all$tot
country_all$not_listed<-ifelse(is.na(country_all$tot), 1, 0)
country_all$BRICS<-apply(cbind(country_all$Brazil,country_all$Russia,country_all$India,country_all$China,country_all$SAfrica), MARGIN=1,FUN=sum, na.rm=TRUE)
country_all$other<-ifelse(is.na(country_all$tot), 0, 1-country_all$BRICS)

#tapply(country_all$tot, country_all$PY, function(x) {sum(is.na(x))})
mat_brics_frac<-matrix(nrow=8, ncol=10)
row.names(mat_brics_frac)<-c("Brazil", 'Russia','India','China','South Africa','BRICS', 'Other','Not listed')
colnames(mat_brics_frac)<-years

mat_brics_frac[1,]<-tapply(country_all$Brazil, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[2,]<-tapply(country_all$Russia, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[3,]<-tapply(country_all$India, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[4,]<-tapply(country_all$China, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[5,]<-tapply(country_all$SAfrica, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[6,]<-tapply(country_all$BRICS, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[7,]<-tapply(country_all$other, country_all$PY, sum, na.rm=TRUE)
mat_brics_frac[8,]<-tapply(country_all$not_listed, country_all$PY, sum, na.rm=TRUE)

svg(file="year_bricsall_frac.svg", width=6, height=4)
par(mar=c(5.1, 4.1, 4.1, 5.1), xpd=TRUE)
barplot(mat_brics_frac[-6,], col=7:1, xlab="Year", ylab="Number of papers") #virtually identical to full authorship credit approach
legend('topright', col=7:1,row.names(mat_brics_frac)[-6] , pch=15, cex=.5, inset=c(-.2,0), pt.cex=1)
dev.off()

####Top 10 countries with fractional authorship####
uniq_country<-unique(bib_all$CO)
uniq_country<-uniq_country[-19]
frac_aut<-strsplit(country_all$AU_CO, ";")

df_frac_aut<-data.frame(matrix(data=NA, nrow=length(frac_aut), ncol=length(uniq_country)))
names(df_frac_aut)<-uniq_country

for (i in 1:length(frac_aut)){
aut_list<-frac_aut[[i]]
n_aut<-length(frac_aut[[i]])
if(!is.na(aut_list[1])) {
  for(j in 1:length(uniq_country)){
    df_frac_aut[i,j]<-sum(str_count(uniq_country[j], aut_list))/n_aut
  }}
else df_frac_aut[i,]<-NA
print(i)
}

frac_countries_tab<-apply(df_frac_aut, 2, sum, na.rm=TRUE)
sort(frac_countries_tab, decreasing=TRUE)

########################################

